import sys,os,re
import numpy as np
import scipy.io.wavfile as wf
from scipy import signal

#fname = 'pdm.csv'
#Fs    = 16000

if len(sys.argv) < 3:
    print('usage: {} input.csv Fs'.format(sys.argv[0]))
    exit(-1)
    
fname = sys.argv[1]
Fs    = int(sys.argv[2])

print('File: {}'.format(fname))
print('Fs:   {}'.format(Fs))

pattern         = re.compile(r'[-/.0-9]*,[ ]*([0-1]{1}),[ ]*([0-1]{1})')
bitstream_right = []
bitstream_left  = []

print('Note: Make sure PDM DATA is before PDM CLK in trace')

with open(fname, 'rb') as fin:
    prev_clk = None

    for line in fin:
        try:
            data, clk = re.findall(pattern, line.decode('utf-8'))[0]
        except:
            continue

        if prev_clk == '1' and clk == '0':
            # Falling clock edge
            if data == '1':
                bitstream_right.append(32767)
            else:
                bitstream_right.append(-32767)
        elif prev_clk == '0' and clk == '1':
            # Rising clock edge
            if data == '1':
                bitstream_left.append(32767)
            else:
                bitstream_left.append(-32767)

        prev_clk = clk


print('Found {} samples in right bitstream'.format(len(bitstream_right)))
print('Found {} samples in left bitstream'.format(len(bitstream_left)))

y_right = signal.decimate(bitstream_right, 80, ftype='fir')
y_left  = signal.decimate(bitstream_left, 80, ftype='fir')

wf.write(re.sub(r'\.[\w]+$', '_left.wav', fname), Fs, y_left.astype(np.int16))
wf.write(re.sub(r'\.[\w]+$', '_right.wav', fname), Fs, y_right.astype(np.int16))